Merged latest reduction improvements

This commit is contained in:
Benoit Steiner
2016-05-26 12:19:33 -07:00
3 changed files with 73 additions and 0 deletions

View File

@@ -325,7 +325,11 @@ __global__ void ReductionInitFullReduxKernelHalfFloat(R, const S, I, half2*);
template <int B, int N, typename S, typename R, typename I>
__global__ void FullReductionKernelHalfFloat(R, const S, I, half*, half2*);
template <int NPT, typename S, typename R, typename I>
<<<<<<< local
__global__ void InnerReductionKernelHalfFloat(R, const S, I, I, half*);
=======
__global__ void InnerReductionKernelHalfFloat(R, const S, I, I, half*, half2*);
>>>>>>> other
#endif
@@ -620,7 +624,11 @@ struct TensorEvaluator<const TensorReductionOp<Op, Dims, ArgType>, Device>
#ifdef EIGEN_HAS_CUDA_FP16
template <typename S, typename R, typename I> friend void internal::ReductionInitFullReduxKernelHalfFloat(R, const S, I, half2*);
template <int B, int N, typename S, typename R, typename I> friend void internal::FullReductionKernelHalfFloat(R, const S, I, half*, half2*);
<<<<<<< local
template <int NPT, typename S, typename R, typename I> friend void internal::InnerReductionKernelHalfFloat(R, const S, I, I, half*);
=======
template <int NPT, typename S, typename R, typename I> friend void internal::InnerReductionKernelHalfFloat(R, const S, I, I, half*, half2*);
>>>>>>> other
#endif
template <int NPT, typename S, typename R, typename I> friend void internal::InnerReductionKernel(R, const S, I, I, typename S::CoeffReturnType*);